pub fn normalize_text(input: &str, limit: usize) -> Option<NormalizedText>Expand description
Normalise text (NFKC), strip control characters, compact whitespace and truncate at grapheme boundaries.
pub fn normalize_text(input: &str, limit: usize) -> Option<NormalizedText>Normalise text (NFKC), strip control characters, compact whitespace and truncate at grapheme boundaries.